==> haskell-tamarin-prover-sapic-1.8.0-42-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-tamarin-prover-sapic.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tamarin-prover-sapic
version:              1.8.0
visibility:           public
id:                   tamarin-prover-sapic-1.8.0-CG2ZEC5gKCI2ftWyZJQYxA
key:                  tamarin-prover-sapic-1.8.0-CG2ZEC5gKCI2ftWyZJQYxA
license:              LicenseRef-GPL
copyright:
    Robert Künnemann, Alexander Dax, CISPA-Helmholtz-Centre Saarbrücken, 2019

maintainer:           Robert Künnemann <robert@kunnemann.de>
author:
    Robert Künnemann <robert@kunnemann.de>,
    Alexander Dax <alexander.dax@cispa.saarland>

homepage:             https://tamarin-prover.github.io/
synopsis:
    Library for input processes in SAPIC calculus for the tamarin prover.

description:
    This is an internal library of the Tamarin prover for
    security protocol verification
    (<hackage.haskell.org/package/tamarin-prover>).

    This library provides a translation from processes stated in the SAPIC calculus into multiset rewrite rules.

category:             Theorem Provers
abi:                  9961fbfbbd42e56b32a5b14402277a59
exposed:              True
exposed-modules:
    Sapic Sapic.Annotation Sapic.Basetranslation Sapic.Bindings
    Sapic.Compression Sapic.Exceptions Sapic.Facts Sapic.LetDestructors
    Sapic.Locks Sapic.ProcessUtils Sapic.ProgressFunction
    Sapic.ProgressTranslation Sapic.ReliableChannelTranslation
    Sapic.Report Sapic.SecretChannels Sapic.States Sapic.Typing
    Sapic.Warnings

import-dirs:          /usr/lib/ghc-9.2.8/site-local/tamarin-prover-sapic-1.8.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/tamarin-prover-sapic-1.8.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tamarin-prover-sapic
hs-libraries:         HStamarin-prover-sapic-1.8.0-CG2ZEC5gKCI2ftWyZJQYxA
depends:
    aeson-2.1.2.1-6EBV889cSS7AqjoZtYoje8
    aeson-pretty-0.8.10-4rSsvAOcfW9KoJnTkslAmZ base-4.16.4.0
    binary-0.8.9.0 bytestring-0.11.4.0 containers-0.6.5.1
    deepseq-1.4.6.1 dlist-1.0-HCxoMn9TirQDgPCFxho7O exceptions-0.10.4
    fclabels-2.0.5.1-5uXMLNw8TBZ6PtJsPzDYC7 mtl-2.2.2
    parallel-3.2.2.0-KgDyPHm89eYAjQsIhXthC1 parsec-3.1.15.0
    process-1.6.16.0 raw-strings-qq-1.1-H0wHvIVgY406DfNVW3VYlH
    safe-0.3.21-iv9yHEgDynJNZkwcC9KXL
    tamarin-prover-term-1.8.0-CBm1Vqb3sf5FT92EvP6krS
    tamarin-prover-theory-1.8.0-KdYPSJQiR3wErZGB0lXBfM
    tamarin-prover-utils-1.8.0-4C7h0036sVCA3zsUh1o6Pb text-1.2.5.0
    transformers-0.5.6.2 uniplate-1.6.13-3kspk5MenPh76qCYq10Rz1

haddock-interfaces:
    /usr/share/doc/haskell-tamarin-prover-sapic/html/tamarin-prover-sapic.haddock

haddock-html:         /usr/share/doc/haskell-tamarin-prover-sapic/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tamarin-prover-sapic-1.8.0-51-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-tamarin-prover-sapic.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tamarin-prover-sapic
version:              1.8.0
visibility:           public
id:                   tamarin-prover-sapic-1.8.0-CP6d9oEGuYr1GnsRt9QBzT
key:                  tamarin-prover-sapic-1.8.0-CP6d9oEGuYr1GnsRt9QBzT
license:              LicenseRef-GPL
copyright:
    Robert Künnemann, Alexander Dax, CISPA-Helmholtz-Centre Saarbrücken, 2019

maintainer:           Robert Künnemann <robert@kunnemann.de>
author:
    Robert Künnemann <robert@kunnemann.de>,
    Alexander Dax <alexander.dax@cispa.saarland>

homepage:             https://tamarin-prover.github.io/
synopsis:
    Library for input processes in SAPIC calculus for the tamarin prover.

description:
    This is an internal library of the Tamarin prover for
    security protocol verification
    (<hackage.haskell.org/package/tamarin-prover>).

    This library provides a translation from processes stated in the SAPIC calculus into multiset rewrite rules.

category:             Theorem Provers
abi:                  619a297fac48f2bc07d39641b03bf460
exposed:              True
exposed-modules:
    Sapic Sapic.Annotation Sapic.Basetranslation Sapic.Bindings
    Sapic.Compression Sapic.Exceptions Sapic.Facts Sapic.LetDestructors
    Sapic.Locks Sapic.ProcessUtils Sapic.ProgressFunction
    Sapic.ProgressTranslation Sapic.ReliableChannelTranslation
    Sapic.Report Sapic.SecretChannels Sapic.States Sapic.Typing
    Sapic.Warnings

import-dirs:          /usr/lib/ghc-9.2.8/site-local/tamarin-prover-sapic-1.8.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/tamarin-prover-sapic-1.8.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tamarin-prover-sapic
hs-libraries:         HStamarin-prover-sapic-1.8.0-CP6d9oEGuYr1GnsRt9QBzT
depends:
    aeson-2.1.2.1-4G6NRH3Yicj9TKX8fXoWTr
    aeson-pretty-0.8.10-3gMGTHlvRlNFcX72WIXlCa base-4.16.4.0
    binary-0.8.9.0 bytestring-0.11.4.0 containers-0.6.5.1
    deepseq-1.4.6.1 dlist-1.0-LNr75TD4CZoKEEzkBmhWjA exceptions-0.10.4
    fclabels-2.0.5.1-HPzRxmUBTyc8gvtWn37Eyd mtl-2.2.2
    parallel-3.2.2.0-KgDyPHm89eYAjQsIhXthC1 parsec-3.1.15.0
    process-1.6.16.0 raw-strings-qq-1.1-VApnGDkS2kGDwmKDL5Udj
    safe-0.3.21-98IVtOx0Wmj8cqPHUtTkEF
    tamarin-prover-term-1.8.0-JFcF18gWq3DGv3xQReLCi
    tamarin-prover-theory-1.8.0-JH6Cd98C9B74imkj2wfIcc
    tamarin-prover-utils-1.8.0-8myE1mY0PchGvNcz2oULiE text-1.2.5.0
    transformers-0.5.6.2 uniplate-1.6.13-1TlVKfWXnEq89IfsWzj5q8

haddock-interfaces:
    /usr/share/doc/haskell-tamarin-prover-sapic/html/tamarin-prover-sapic.haddock

haddock-html:         /usr/share/doc/haskell-tamarin-prover-sapic/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
